@@ -32,21 +32,22 @@ class TestZBuildDeploy(src.jadecobra.tester.TestCase):
         )
 
     def test_z_published_version_is_test_version(self):
-        self.assert_published_version_is_source_version()
-        try:
-            self.assertEqual(
-                src.jadecobra.toolkit.publish(True),
-                0
-            )
-        except AssertionError:
+        if src.jadecobra.toolkit.git_diff():
             try:
                 self.version.update()
             except FileNotFoundError:
                 pass
-            finally:
-                self.assertEqual(
-                    src.jadecobra.toolkit.publish(True),
-                    0
-                )
-                self.get_latest_published_version()
-                self.assert_published_version_is_source_version()
\ No newline at end of file
+            try:
+                self.assert_published_version_is_source_version()
+            except AssertionError:
+                try:
+                    self.assertEqual(
+                        src.jadecobra.toolkit.publish(True),
+                        0
+                    )
+                except AssertionError:
+                    self.assertIsNone(
+                        src.jadecobra.toolkit.publish(True)
+                    )
+                    self.get_latest_published_version()
+                    self.assert_published_version_is_source_version()
\ No newline at end of file
